@@ -33,7 +33,9 @@ typedef struct _GisPage      GisPage;
 #include "gis-driver.h"
 #include "gis-assistant.h"
 #include "gis-page.h"
+#include "gis-pkexec.h"
 #include "gis-keyring.h"
+#include "gis-util.h"
 
 void gis_ensure_stamp_files (GisDriver *driver);
 gboolean gis_get_mock_mode (void);
